@@ -3,19 +3,11 @@ local vm      = require 'vm'
 local lang    = require 'language'
 local guide   = require 'parser.guide'
 local await   = require 'await'
-local infer   = require 'vm.infer'
 
 local skipCheckClass = {
     ['unknown']       = true,
     ['any']           = true,
     ['table']         = true,
-    ['nil']           = true,
-    ['number']        = true,
-    ['integer']       = true,
-    ['boolean']       = true,
-    ['function']      = true,
-    ['userdata']      = true,
-    ['lightuserdata'] = true,
 }
 
 ---@async
@@ -29,17 +21,17 @@ return function (uri, callback)
     local function checkUndefinedField(src)
         await.delay()
 
-        if #vm.getDefs(src) > 0 then
+        if vm.hasDef(src) then
             return
         end
         local node = src.node
         if node then
             local ok
-            for view in infer.getInfer(node):eachView() do
-                if not skipCheckClass[view] then
-                    ok = true
-                    break
+            for view in vm.getInfer(node):eachView(uri) do
+                if skipCheckClass[view] then
+                    return
                 end
+                ok = true
             end
             if not ok then
                 return
@@ -62,5 +54,4 @@ return function (uri, callback)
     end
     guide.eachSourceType(ast.ast, 'getfield',  checkUndefinedField)
     guide.eachSourceType(ast.ast, 'getmethod', checkUndefinedField)
-    guide.eachSourceType(ast.ast, 'getindex',  checkUndefinedField)
 end
